@@ -2,7 +2,8 @@
 
 =head1 NAME
 
-JMX::Jmx4Perl::Response - Encapsulates a jmx4perl response 
+JMX::Jmx4Perl::Response - Encapsulates as JMX Response as it comes from the
+observered Server
 
 =head1 SYNOPSIS
 
@@ -56,7 +57,6 @@ sub new {
 Return the status code of this response. Status codes are modelled after HTTP
 return codes. C<200> is the code for a suceeded request. Any code in the range
 500 - 599 specifies an error.
-
 =cut
 
 sub status {
@@ -74,7 +74,7 @@ sub is_ok {
     return shift->{status} == 200;
 }
 
-=item $fault = $response->is_error()
+=item $fault = $resonse_is_error()
 
 Opposite of C<is_ok>, i.e. return true if the status code is B<not> equal to
 200 
@@ -107,9 +107,8 @@ sub stacktrace { return shift->{stacktrace}; }
 
 =item $content = $response->value() 
 
-Return the content of this response, which is a represents the JSON response as
-returned by the Java agent as a hash reference value. This is set only when C<is_ok> is
-true.
+Return the content of this response, which is a JSON representation of the
+result as returned by the Java agent. This is set only when C<is_ok> is true. 
 
 =cut
 
@@ -127,7 +126,7 @@ sub request {
     return shift->{request};
 }
 
-=back
+=back 
 
 =head1 LICENSE
 
